@@ -33,9 +33,9 @@
 #' @importFrom stringr str_detect str_replace_all str_to_upper str_to_title str_replace
 #' @importFrom tidyr tibble separate gather
 #' @importFrom utils tail
-#' @importFrom zip unzip
 #' @importFrom stats na.omit
 #' @importFrom utils tail
+#' @importFrom data.table fread
 
 read_NPX <- function(filename) {
   # If the file is csv or txt read_NPX assumes Explore NPX data in long format
@@ -76,8 +76,10 @@ read_NPX_explore <- function(filename) {
   # Check that all column names are present
   # We have had 5 column names versions so far: 1, 1.1 and 2, 2.1, and 3
   # please add newer versions to the list chronologically
-  header_standard <- c("SampleID", "OlinkID", "UniProt", "Assay",
-                       "Panel", "PlateID", "QC_Warning", "NPX")
+  header_base <- c("SampleID", "OlinkID", "UniProt", "Assay",
+                       "Panel", "PlateID", "NPX")
+
+  header_standard <- c(header_base, "QC_Warning")
 
   header_quant_standard <- c("SampleID", "OlinkID", "UniProt", "Assay",
                        "Panel", "PlateID", "QC_Warning")
@@ -190,7 +192,41 @@ read_NPX_explore <- function(filename) {
                              "PlateLOD",
                              "QC.Deviation.Inc.Ctrl",
                              "QC.Deviation.Det.Ctrl",
-                             "Olink.NPX.Signature.Version")
+                             "Olink.NPX.Signature.Version"),
+    "header_csv_hp" = c(header_base,
+                        "SampleType",
+                        "WellID",
+                        "DataAnalysisRefID",
+                        "AssayType",
+                        "Block",
+                        "Counts",
+                        "ExtNPX",
+                        "Normalization",
+                        "PCNormalizedNPX",
+                        "AssayQC",
+                        "SampleQC",
+                        "SoftwareVersion",
+                        "SoftwareName"),
+    "header_ext_csv_hp" = c(header_base,
+                            "SampleType",
+                            "WellID",
+                            "DataAnalysisRefID",
+                            "AssayType",
+                            "Block",
+                            "Count",
+                            "ExtNPX",
+                            "Normalization",
+                            "PCNormalizedNPX",
+                            "AssayQC",
+                            "SampleQC",
+                            "SoftwareVersion",
+                            "SoftwareName",
+                            "IntraCV",
+                            "InterCV",
+                            "SampleBlockQCWarn",
+                            "SampleBlockQCFail",
+                            "BlockQCFail",
+                            "AssayQCWarn")
 
   )
 
@@ -248,6 +284,11 @@ read_NPX_explore <- function(filename) {
       dplyr::mutate(Panel = trimws(Panel, which = "right")) %>%
       dplyr::select(-Panel_Start, -Panel_End)
   }
+  if ("Quantified_value" %in% names(out)){
+    message("QUANT data detected. Some downstream functions may not be supported.")
+    out <- out %>%
+      mutate(Quantified_value = as.numeric(Quantified_value))
+  }
 
   return(out)
 
