@@ -1,6 +1,7 @@
 skip_on_cran()
 skip_if_not_installed("ggplot2", minimum_version = "3.4.0")
-
+skip_if_not_installed("lme4")
+skip_if_not_installed("lmerTest")
 # Suppress messages
 sink(file = file(tempfile(), open = "wt"), type = "message")
 
